#######################################
### DO NOT EDIT THE FOLLOWING LINES ###

### How to build documentation ###

.SUFFIXES: .tr .t .txt .man .mkd .html .pdf .1 .7 .LICENSE .sh
.INTERMEDIATE: $(MAN1:=.t) $(MAN7:=.t) $(RDM:=.t) $(DOC:=.t)

vpath bsd4.tr ../share/
vpath bsd2.tr ../share/
vpath cddl.tr ../share/

TROFFENV=export TROFFMACS=$(MACDIR)/ TROFFONTS=$(OTFDIR)/; unset UTMAC

.tr.t: 
	$(SOELIM) $< | $(FELIM) | $(UGRIND) > $@
.t.txt:
	$(TROFFENV); $(NROFF) -Tlocale -mut $< > $@
.t.LICENSE:
	$(TROFFENV); $(NROFF) -Tlocale -mut $< > $@
README: readme.t
	$(TROFFENV); $(NROFF) -Tlocale -mut $< > $@
.t.mkd:
	$(TROFFENV); $(NROFF) -Tlocale -muw $< > $@
.t.man:
	$(TROFFENV); $(NROFF) -Tlocale -mum $< > $@
.t.html:
	$(TROFFENV); $(PREXML) < $< | $(NROFF) -Tlocale -mux | $(POSTXML) \
	| $(TRXTR) utroff.org | sed -e "s#@WEBURL@#$(WEBURL)#g; \
	s#@PUBURL@#$(PUBURL)#g; s#@RELEASE@#$(RELEASE)#g" > $@
.t.pdf:
	$(TROFFENV); $(TROFF) -rRH=0 -mus $< > /dev/null
	$(TROFFENV); $(TROFF) -mus $< | $(DPOST) | $(PS2PDF) - > $@

$(LOG:=.tr): VERSION
	echo ".H2 Changes of $(WHO)" > $@
	$(CLOG) -t VERSION | $(SLELIM) >> $@

.man.1 .man.7:
	sed -e "s|@BIN@|$(BIN)|g; \
	s|@BINDIR@|$(BINDIR)|g; \
	s|@LIBDIR@|$(LIBDIR)|g; \
	s|@MACDIR@|$(MACDIR)|g; \
	s|@REFDIR@|$(REFDIR)|g; \
	s|@XSLDIR@|$(XSLDIR)|g;" $< > $@

CHANGES: VERSION
	$(CLOG) $< > $@

lookup.tr:
	echo -e ".PL\nSee the following files:" >> $@
	test -z "$(WEB)" || for f in $(WEB); do \
	echo -e ".LP $$f ,\n.LU $(WEBURL)/$$f.html" >> $@; \
	done
	echo -e ".LP readme ,\n.LU $(WEBURL)/man/$(WHO)-readme.html" >> $@; \
	for f in $(MAN1) $(MAN7) $(LIC); do \
	echo -e ".LP $$f ,\n.LU $(WEBURL)/man/$$f.html" >> $@; \
	done
	test -z "$(LOG)" || for f in $(LOG); do \
	echo -e ".LP $$f ,\n.LU $(WEBURL)/log/$(WHO).html" >> $@; \
	done
	echo "or download" >> $@
	test -z "$(DOC)" || for f in $(DOC); do \
	echo -e ".LP $$f.pdf .\n.LU $(PUBURL)/doc/$$f.pdf" >> $@; \
	done


### Binaries ###

.c.o:
	$(CC) $(CFLAGS) $(WARN) $(FLAGS) $(EUC) $(CPPFLAGS) -c $<

.sh:
	sed -e "s|@SHELL@|$(SHELL)|g; s|@BINDIR@|$(BINDIR)|g; \
	s|@MANDIR@|$(MANDIR)|g; s|@LIBDIR@|$(LIBDIR)|g; \
	s|@OTFDIR@|$(OTFDIR)|g; s|@MACDIR@|$(MACDIR)|g" \
	$< > $@


### Where to install? ###

$(DESTDIR)$(BINDIR) \
$(DESTDIR)$(REFDIR) \
$(DESTDIR)$(LIBDIR) \
$(DESTDIR)$(MACDIR) \
$(DESTDIR)$(XSLDIR) \
$(DESTDIR)$(DOCDIR) \
$(DESTDIR)$(WEBDIR) \
$(DESTDIR)$(WEBDIR)/log \
$(DESTDIR)$(PUBDIR)/doc \
$(DESTDIR)$(PUBDIR)/pub \
$(DESTDIR)$(PUBDIR)/www \
$(DESTDIR)$(WEBDIR)/man \
$(DESTDIR)$(MANDIR)/man1 \
$(DESTDIR)$(MANDIR)/man7:
	test -d $@ || mkdir -p $@


### How  to install? ###

$(DESTDIR)$(BINDIR)/%: % $(DESTDIR)$(BINDIR)
	$(INSTALL) -c $(@F) $@
$(DESTDIR)$(LIBDIR)/%: % $(DESTDIR)$(LIBDIR)
	$(INSTALL) -c -m 644 $(@F) $@
$(DESTDIR)$(MACDIR)/%: % $(DESTDIR)$(MACDIR)
	$(INSTALL) -c -m 644 $(@F) $@
$(DESTDIR)$(REFDIR)/%: % $(DESTDIR)$(REFDIR)
	$(INSTALL) -c $(@F) $@
$(DESTDIR)$(XSLDIR)/%: % $(DESTDIR)$(XSLDIR)
	$(INSTALL) -c -m 644 $(@F) $@
$(DESTDIR)$(DOCDIR)/%: % $(DESTDIR)$(DOCDIR)
	$(INSTALL) -c -m 644 $(@F) $@
$(DESTDIR)$(WEBDIR)/%: % $(DESTDIR)$(WEBDIR)
	$(INSTALL) -c -m 644 $(@F) $@
$(DESTDIR)$(WEBDIR)/man/$(WHO)-readme.html: readme.html $(DESTDIR)$(WEBDIR)/man
	$(INSTALL) -c -m 644 readme.html $@
$(DESTDIR)$(WEBDIR)/log/$(WHO).html: log.html $(DESTDIR)$(WEBDIR)/log
	$(INSTALL) -c -m 644 log.html $@
$(DESTDIR)$(PUBDIR)/doc/%: % $(DESTDIR)$(PUBDIR)/doc
	$(INSTALL) -c -m 644 $(@F) $@
$(DESTDIR)$(PUBDIR)/pub/%: % $(DESTDIR)$(PUBDIR)/pub
	$(INSTALL) -c -m 644 $(@F) $@
$(DESTDIR)$(PUBDIR)/www/%: % $(DESTDIR)$(PUBDIR)/www
	$(INSTALL) -c -m 644 $(@F) $@
$(DESTDIR)$(WEBDIR)/man/%: % $(DESTDIR)$(WEBDIR)/man
	$(INSTALL) -c -m 644 $(@F) $@
$(DESTDIR)$(MANDIR)/man1/%: % $(DESTDIR)$(MANDIR)/man1
	$(INSTALL) -c -m 644 $(@F) $@
$(DESTDIR)$(MANDIR)/man7/%: % $(DESTDIR)$(MANDIR)/man7
	$(INSTALL) -c -m 644 $(@F) $@

### How to strip and remove ? ### 

# Use fake suffixe trick

.SUFFIXES: .STRIP .REMOVE

%.STRIP: %
	$(STRIP) $(@:.STRIP=)

%.REMOVE:
	rm -f $(@:.REMOVE=)




### What to build ? ###

bin: $(BIN) $(REF) $(TMAC)

man: $(MAN1:=.1) \
	$(MAN7:=.7)

pub: $(RDM:readme=README) \
	$(LIC:=.LICENSE) \
	$(MAN1:=.man) \
	$(MAN7:=.man) \
	$(LOG:=.tr) \
	$(PUB) \
	CHANGES
	rm -f *.o *.t *.1 *.7 *.pdf *.html *.ig lookup.tr \
	$(CLEAN) $(BIN) $(REF) $(TMAC) $(LIB)

doc: $(DOC:=.pdf) $(DEMO)

web: $(WEB:=.html) \
	$(DOC:=.pdf) \
	$(MAN1:=.html) \
	$(MAN7:=.html) \
	$(LIC:=.html) \
	$(LOG:=.html) \
	$(RDM:=.html)


### Where to install ? ###

BINFILES+= $(BIN:%=$(DESTDIR)$(BINDIR)/%) \
	$(LIB:%=$(DESTDIR)$(LIBDIR)/%) \
	$(REF:%=$(DESTDIR)$(REFDIR)/%) \
	$(TMAC:%=$(DESTDIR)$(MACDIR)/%) \
	$(XSL:%=$(DESTDIR)$(XSLDIR)/%)

MANFILES+= $(MAN1:%=$(DESTDIR)$(MANDIR)/man1/%.1) \
	$(MAN7:%=$(DESTDIR)$(MANDIR)/man7/%.7)

DOCFILES+= $(DOC:%=$(DESTDIR)$(DOCDIR)/%.pdf) \
	$(DEMO:%=$(DESTDIR)$(DOCDIR)/%)

WEBFILES+= $(WEB:%=$(DESTDIR)$(WEBDIR)/%.html) \
	$(MAN1:%=$(DESTDIR)$(WEBDIR)/man/%.html) \
	$(MAN7:%=$(DESTDIR)$(WEBDIR)/man/%.html) \
	$(RDM:%=$(DESTDIR)$(WEBDIR)/man/$(WHO)-%.html) \
	$(LIC:%=$(DESTDIR)$(WEBDIR)/man/%.html) \
	$(LOG:%=$(DESTDIR)$(WEBDIR)/log/$(WHO).html) \
	$(DOC:%=$(DESTDIR)$(PUBDIR)/doc/%.pdf) \
	$(DEMO:%=$(DESTDIR)$(PUBDIR)/doc/%)


### Here we go ! ###

installbin: $(STR:=.STRIP) $(BINFILES)
uninstallbin: $(BINFILES:=.REMOVE)
installman: $(MANFILES)
uninstallman: $(MANFILES:=.REMOVE)
installdoc: $(DOCFILES)
uninstalldoc: $(DOCFILES:=.REMOVE)
installweb:	$(WEBFILES)
uninstallweb: $(WEBFILES:=.REMOVE)
install: installbin installman
uninstall: uninstallbin uninstallman
all: man bin
world: all doc web
installword: install installdoc installweb
uninstallworld: uninstall uninstalldoc uninstallweb

clean:
	rm -f *.o *.t *.1 *.7 *.pdf *.html *.ig lookup.tr \
	$(CLEAN) $(BIN) $(REF) $(TMAC) $(LIB)

mrproper: clean
	rm -f README *.LICENSE CHANGES *.man $(LOG).tr $(PUB)
	- ci -j -q RCS/*
	- rcsclean makefile

co:
	co -l RCS/*

# $Id: include.mk,v 0.18 2014/03/12 19:22:28 pj Exp pj $
